@@ -4,14 +4,9 @@ use anchor_lang::prelude::*;
 use anchor_spl::token::TokenAccount;
 use num_traits::ToPrimitive;
 use spl_math::uint::U192;
-use vipers::invariant;
-use vipers::unwrap_int;
+use vipers::prelude::*;
 
-use crate::ClaimEvent;
-use crate::ClaimRewards;
-use crate::Rewarder;
-use crate::DEFAULT_CLAIM_FEE_MILLIBPS;
-use crate::MAX_BPS;
+use crate::{ClaimEvent, ClaimRewards, Rewarder, DEFAULT_CLAIM_FEE_MILLIBPS, MAX_BPS};
 
 impl Rewarder {
     /// Computes the amount of rewards a [crate::Quarry] should receive, annualized.
